#' Marshall's Favorite Bars
#'
#' Data from How I met Your Mother: Marshall's Favorite Bars.
#'
#' @section Variables:
#'
#' \itemize{
#'
#'  \item \code{bar}: Bar's name.
#'  \item \code{percent}: In percentage of awesomeness
#'
#' }
#'
#' @docType data
#' @name favorite_bars
#' @usage favorite_bars
#' @format A \code{data frame} with 5 observations and 2 variables.
"favorite_bars"
